@@ -208,7 +208,7 @@ reactsWith(Blacklist blacklist)
 
 	public static void main(String[] args) throws Exception {
 		
-		
+		Integer  controlVersion=2;
 		String propFilePath = null;
         if(args==null){
         	propFilePath = "config.properties";
@@ -229,7 +229,7 @@ reactsWith(Blacklist blacklist)
 		if(gc.isDoSpaim()){
 			MainGenerator b = new MainGenerator();
 			LogUtils.info("***start spaim generator");
-			b.runDoSpaim(gc);
+			b.runDoSpaim(gc,  controlVersion);
 		}
 		if(gc.isDoMerge()){
 			MainGenerator b = new MainGenerator();
@@ -312,7 +312,7 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 }
 
 	 
-	public   void  runDoSpaim(GraphConfig gc) throws Exception {
+	public   void  runDoSpaim(GraphConfig gc,Integer  controlVersion) throws Exception {
 		
 		
 		
@@ -347,7 +347,7 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 				doGenerateBlackList, addEntityReference,
 				addComplexComponent, doGraphml, graphmlTemplateFilePath,
 				doDB, doDBtoFile, doHub, hubFile, dBFile,
-				dbDriver, dbUser, dbUrl, dbPassword
+				dbDriver, dbUser, dbUrl, dbPassword,   controlVersion
 				);
 	
 	}
@@ -355,7 +355,7 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 	public void runDoSpaim(String blackListFile, String graphmlOutputFilePath, File inputBiopaxFile,
 			Boolean doGenerateBlackList, Boolean addEntityReference, Boolean addComplexComponent, Boolean doGraphml,
 			String graphmlTemplateFilePath, Boolean doDB, Boolean doDBtoFile, Boolean doHub, String hubFile,
-			String dBFile, String dbDriver, String dbUser, String dbUrl, String dbPassword)
+			String dBFile, String dbDriver, String dbUser, String dbUrl, String dbPassword, Integer controlVersion)
 			throws Exception {
 		
 		
@@ -398,7 +398,8 @@ public static void  writeBioPax3ToFile(String outFilePath, Model  modelCurrent )
 			SpaimGraphGenerator sgg = new SpaimGraphGenerator(
 					 addEntityReference,
 					 addComplexComponent,
-					 mapBench);
+					 mapBench,controlVersion);
+			
 			 rp = sgg.rawPatternSearch(model,sifSelection.getSelectedValues().toArray(new SIFType[]{}),
 					 blacklist);
 			 LogUtils.info("**************REPORT*******************");
