@@ -7,10 +7,11 @@ __docformat__ = 'reStructuredText'
 
 
 import sys
+import logging
 import copy
 import pandas as pd
 import numpy as np 
-import logging
+
 from graph_tool.all import random_graph, label_components
 import graph_tool.all as gt
 
@@ -20,7 +21,8 @@ from pybiomart.dataset import   Filter
  
 from pax2graphml import utils, properties, graph_explore
  
-
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
 
 def sub_graph_by_value(g,targets,annot_keys,add_void=False,void_symbol=None):
     
@@ -36,7 +38,7 @@ def sub_graph_by_value(g,targets,annot_keys,add_void=False,void_symbol=None):
   :rtype: list 
  
   """ 
-  
+
   extend_to_cc=False     
   subgraphList=list()
   for tar in targets:
@@ -73,6 +75,8 @@ def subgraphs_by_datasource(g,add_void=False,void_symbol=""):
  
  
     """
+    if g is None:
+       logger.info("warning graph is None")
     annot_key="provider"
     providerList=properties.property_values(g,annot_key)
     annot_keys=[annot_key]
@@ -96,7 +100,7 @@ def connected_component_by_annotation(g,targ,annot_keys,add_void=False,extend_to
  
     """ 
 
-    
+
     targmap=dict()
     targmapcc=dict()
     revnidmap=dict()
@@ -188,6 +192,7 @@ def define_boolean_filter(gr,att,val, usecase=True):
      :return: a filter as a dictionnary (node index,True/False)
      :rtype: dict  
      """ 
+
      vfilter = gr.new_vertex_property("bool");
      lval  =list()
      if type(val) is list: 
@@ -229,6 +234,8 @@ def filter_from_boolean_filter(gr,vfilter):
      :rtype: graph 
  
      """
+
+     
      u = gt.GraphView(gr, vfilt=vfilter)
      u=gt.Graph(u, prune=True)
      return u
@@ -247,6 +254,8 @@ def filter_by_node_attribute(gr,att,val):
      """
      u=gt.GraphView(gr, vfilt=lambda v: gr.vp[att][v]==val)
      u=gt.Graph(u, prune=True)
+     if u is None:
+       logger.info("warning graph is None")
      return u
 
 
@@ -265,8 +274,8 @@ def largest_connected_component(g, directed=False):
 	lCCfilt = gt.label_largest_component(g, directed=directed)
 	lCC = gt.GraphView(g, vfilt=lCCfilt)
 	lCC=gt.Graph(lCC, prune=True)
-	logging.info("\nlargest CC order: %s" %len(list(lCC.vertices())))
-	logging.info("largest CC size: %s" %len(list(lCC.edges())))
+	logger.info("\nlargest CC order: %s" %len(list(lCC.vertices())))
+	logger.info("largest CC size: %s" %len(list(lCC.edges())))
 	return lCC
 
  
@@ -284,8 +293,8 @@ def remove_largest_cc(g, directed=False):
 		woLCCfilt.a[i]= 1-woLCCfilt.a[i]
 	woLCC = gt.GraphView(g, vfilt=woLCCfilt)
 	woLCC=gt.Graph(woLCC, prune=True)
-	logging.info("graph without largest CC order: %s" %len(list(woLCC.vertices())))
-	logging.info("graph without largest CC size: %s" %len(list(woLCC.edges())))
+	logger.info("graph without largest CC order: %s" %len(list(woLCC.vertices())))
+	logger.info("graph without largest CC size: %s" %len(list(woLCC.edges())))
 	return woLCC
 
 
@@ -423,7 +432,7 @@ def merge_graph(gr1,gr2,properties_list,add_void=False,caseSensitive=True):
  
         if domerge==True:
            
-            logging.info(utils.node_to_string(gr1, second_node, " , "))
+            logger.info(utils.node_to_string(gr1, second_node, " , "))
             ki=int(second_node)
             if ki in domergeMap:
                 kset=domergeMap[ki]
@@ -476,7 +485,7 @@ def merge_graph(gr1,gr2,properties_list,add_void=False,caseSensitive=True):
   for nid in nmap.keys(): 
         u=nmap[nid]
         if rprop[u] is not None and rprop[u]==1:
-           logging.info("  -->>>>"+utils.node_to_string(gr1, u, " , ")) 
+           logger.info("  -->>>>"+utils.node_to_string(gr1, u, " , ")) 
            narr.append(u)
   if len(narr)>0:
            gr1.remove_vertex(narr)
@@ -530,7 +539,7 @@ def merge_node_by_property(gr1,properties_list,add_void=False,caseSensitive=True
  
         if domerge==True:
             second_node=u
-            logging.info(utils.node_to_string(gr1, second_node, " , "))
+            logger.info(utils.node_to_string(gr1, second_node, " , "))
             ki=int(second_node)
             if ki in domergeMap:
                 kset=domergeMap[ki]
@@ -557,7 +566,7 @@ def merge_node_by_property(gr1,properties_list,add_void=False,caseSensitive=True
            ulist=list(domergeMap[nid])
            for ix in ulist: 
               u=nmap[ix]
-              logging.info("-v--%s   "%(int(v) )) 
+              logger.info("-v--%s   "%(int(v) )) 
               if int(u)!=int(v):
                  st=set()  
                  st.add(str(ix))
@@ -565,7 +574,7 @@ def merge_node_by_property(gr1,properties_list,add_void=False,caseSensitive=True
                  k=",".join(sorted(st))
                  if k not in rmm.keys():
                     rmm[k]=1     
-                    logging.info("-v u--%s %s "%(int(v),int(u))) 
+                    logger.info("-v u--%s %s "%(int(v),int(u))) 
                     rprop[u]=2
                     merge_nodes(gr1,u,v,False)
          
@@ -573,7 +582,7 @@ def merge_node_by_property(gr1,properties_list,add_void=False,caseSensitive=True
   for nid in nmap.keys(): 
         u=nmap[nid]
         if rprop[u] is not None and rprop[u]==2:
-           logging.info("  -->>>>"+utils.node_to_string(gr1, u, " , ")) 
+           logger.info("  -->>>>"+utils.node_to_string(gr1, u, " , ")) 
            narr.append(u)
   if len(narr)>0:
            gr1.remove_vertex(narr)
@@ -625,11 +634,11 @@ def sub_graph_filter(g, iteration_count, central_node, direction=all, node_limit
                     if (n not in neighbourhood):
                         newNeighbours.append(n)
         else:
-            logging.info("\nERROR: DIRECTION UNDEFINED (must be {all, in, out})\n")
+            logger.info("\nERROR: DIRECTION UNDEFINED (must be {all, in, out})\n")
             return -1
 
         if (newNeighbours==[]):
-            logging.info("\nBREAK: NO NEW NEIGHBOURS AT ITERATION %s\n" %i)
+            logger.info("\nBREAK: NO NEW NEIGHBOURS AT ITERATION %s\n" %i)
             break
         if (neighbour_count is not None):#choose randomly a given number (if not none) of neighbours
             newNeighbours=np.random.choice(newNeighbours, int(neighbour_count))
@@ -637,7 +646,7 @@ def sub_graph_filter(g, iteration_count, central_node, direction=all, node_limit
         newNeighbours=np.unique(newNeighbours)
         neighbourhood=np.concatenate((neighbourhood, newNeighbours))
         if (node_limit is not None and len(neighbourhood)>= int(node_limit)):#break if cardinality is over the limit
-            logging.info("\nBREAK: CARDINALITY REACHED THE GIVEN LIMIT\n")
+            logger.info("\nBREAK: CARDINALITY REACHED THE GIVEN LIMIT\n")
             break
 
 
@@ -669,13 +678,14 @@ def subgraph_by_direction(g, iteration_count, chosen_node_id=None, direction="al
     else:
         central_node=np.random.choice(g.get_vertices())
      
-    logging.info("\nCentral Node Name: "+str(g.vp.name[central_node]))
-    logging.info("Central Node Id: "+str(g.vp._graphml_vertex_id[central_node]))
-    logging.info("Central Node Degree: "+str(g.get_total_degrees([central_node])))
+    logger.info("\nCentral Node Name: "+str(g.vp.name[central_node]))
+    logger.info("Central Node Id: "+str(g.vp._graphml_vertex_id[central_node]))
+    logger.info("Central Node Degree: "+str(g.get_total_degrees([central_node])))
 
     vSubFilt=sub_graph_filter(g, iteration_count, central_node, direction, node_limit, neighbour_count)
     subG = gt.GraphView(g, vfilt=vSubFilt)
     subG=gt.Graph(subG, prune=True)
+    return subG
 
 
 
