@@ -378,6 +378,16 @@ def color_edges(g):
 
 
 
+def save_yed_graphml(g,graphmlOutFile):
+ 
+      """save graphml file enriched by graphics to be displayed by yEd editor
+        :param g :  a graph instance   
+        :param graphml_file: a graphml file
+        :return: void
+        :rtype: None 
+      """ 
+      save_graphml(g,graphmlOutFile,True)
+      utils.__format_graphml_yed(graphmlOutFile)
 
 
 
